summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qpopupmenu_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qpopupmenu_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qpopupmenu_imp.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/kjsembed/qtbindings/qpopupmenu_imp.cpp b/kjsembed/qtbindings/qpopupmenu_imp.cpp
index f11c9a3b..1c94776a 100644
--- a/kjsembed/qtbindings/qpopupmenu_imp.cpp
+++ b/kjsembed/qtbindings/qpopupmenu_imp.cpp
@@ -23,12 +23,12 @@
*/
namespace KJSEmbed {
-TTQPopupMenuImp::TQPopupMenuImp( KJS::ExecState *exec, int mid, bool constructor )
+TQPopupMenuImp::TQPopupMenuImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQPopupMenuImp::~TQPopupMenuImp()
+TQPopupMenuImp::~TQPopupMenuImp()
{
}
@@ -43,7 +43,7 @@ void TQPopupMenuImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &objec
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -85,7 +85,7 @@ void TQPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -98,25 +98,25 @@ void TQPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TTQPopupMenu pointer from an Object.
*/
-TTQPopupMenu *TQPopupMenuImp::toTQPopupMenu( KJS::Object &self )
+TQPopupMenu *TQPopupMenuImp::toTQPopupMenu( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQPopupMenu *>( obj );
+ return dynamic_cast<TQPopupMenu *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TTQPopupMenu" )
+ if ( op->typeName() != "TQPopupMenu" )
return 0;
- return op->toNative<TTQPopupMenu>();
+ return op->toNative<TQPopupMenu>();
}
/**
@@ -134,7 +134,7 @@ KJS::Object TQPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &ar
break;
}
- TTQString msg = i18n("TQPopupMenuCons has no constructor with id '%1'").arg(id);
+ TQString msg = i18n("TQPopupMenuCons has no constructor with id '%1'").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -142,17 +142,17 @@ KJS::Object TQPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &ar
KJS::Object TQPopupMenuImp::TQPopupMenu_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TTQWidget *
return KJS::Object();
- TTQWidget * arg0; // Dummy
+ TQWidget * arg0; // Dummy
const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
- // We should now create an instance of the TTQPopupMenu object
+ // We should now create an instance of the TQPopupMenu object
- TTQPopupMenu *ret = new TTQPopupMenu(
+ TQPopupMenu *ret = new TQPopupMenu(
arg0,
arg1 );
@@ -238,7 +238,7 @@ KJS::Value TQPopupMenuImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- TTQString msg = i18n( "TQPopupMenuImp has no method with id '%1'" ).arg( id );
+ TQString msg = i18n( "TQPopupMenuImp has no method with id '%1'" ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -246,7 +246,7 @@ KJS::Value TQPopupMenuImp::call( KJS::ExecState *exec, KJS::Object &self, const
KJS::Value TQPopupMenuImp::popup_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint arg0 = extractTQPoint(exec, args, 0);
+ TQPoint arg0 = extractTQPoint(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -291,7 +291,7 @@ KJS::Value TQPopupMenuImp::isCheckable_6( KJS::ExecState *exec, KJS::Object &obj
KJS::Value TQPopupMenuImp::setFont_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQFont arg0 = extractTQFont(exec, args, 0);
+ TQFont arg0 = extractTQFont(exec, args, 0);
instance->setFont(
arg0 );
@@ -327,7 +327,7 @@ KJS::Value TQPopupMenuImp::exec_10( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQPopupMenuImp::exec_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint arg0 = extractTQPoint(exec, args, 0);
+ TQPoint arg0 = extractTQPoint(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -352,7 +352,7 @@ KJS::Value TQPopupMenuImp::setActiveItem_12( KJS::ExecState *exec, KJS::Object &
KJS::Value TQPopupMenuImp::sizeHint_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQSize ret;
+ TQSize ret;
ret = instance->sizeHint( );
return convertToValue( exec, ret );
@@ -374,7 +374,7 @@ KJS::Value TQPopupMenuImp::idAt_14( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQPopupMenuImp::idAt_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint arg0 = extractTQPoint(exec, args, 0);
+ TQPoint arg0 = extractTQPoint(exec, args, 0);
int ret;
ret = instance->idAt(
@@ -422,7 +422,7 @@ KJS::Value TQPopupMenuImp::itemGeometry_19( KJS::ExecState *exec, KJS::Object &o
{
int arg0 = extractInt(exec, args, 0);
- TTQRect ret;
+ TQRect ret;
ret = instance->itemGeometry(
arg0 );
@@ -98,25 +98,25 @@ void TQPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TTQPopupMenu pointer from an Object.
+ * Extract a TQPopupMenu pointer from an Object.
*/
@@ -142,17 +142,17 @@ KJS::Object TQPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &ar
KJS::Object TQPopupMenuImp::TQPopupMenu_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter TTQWidget *
+ // Unsupported parameter TQWidget *
return KJS::Object();